KernelConfigBuilder

Struct KernelConfigBuilder 

pub struct KernelConfigBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> KernelConfigBuilder<S>

pub fn build(self) -> KernelConfig
where S: IsComplete,

Finish building and return the requested object

pub fn environment( self, value: Environment, ) -> KernelConfigBuilder<SetEnvironment<S>>
where S::Environment: IsUnset,

Optional (Some / Option setters). Default: Environment::Backtest.

The kernel environment context.

pub fn maybe_environment( self, value: Option<Environment>, ) -> KernelConfigBuilder<SetEnvironment<S>>
where S::Environment: IsUnset,

Optional (Some / Option setters). Default: Environment::Backtest.

The kernel environment context.

pub fn trader_id(self, value: TraderId) -> KernelConfigBuilder<SetTraderId<S>>
where S::TraderId: IsUnset,

Optional (Some / Option setters). Default: <TraderId as Default>::default().

The trader ID for the node (must be a name and ID tag separated by a hyphen).

pub fn maybe_trader_id( self, value: Option<TraderId>, ) -> KernelConfigBuilder<SetTraderId<S>>
where S::TraderId: IsUnset,

Optional (Some / Option setters). Default: <TraderId as Default>::default().

The trader ID for the node (must be a name and ID tag separated by a hyphen).

pub fn load_state(self, value: bool) -> KernelConfigBuilder<SetLoadState<S>>
where S::LoadState: IsUnset,

Optional (Some / Option setters). Default: false.

If trading strategy state should be loaded from the database on start.

pub fn maybe_load_state( self, value: Option<bool>, ) -> KernelConfigBuilder<SetLoadState<S>>
where S::LoadState: IsUnset,

Optional (Some / Option setters). Default: false.

If trading strategy state should be loaded from the database on start.

pub fn save_state(self, value: bool) -> KernelConfigBuilder<SetSaveState<S>>
where S::SaveState: IsUnset,

Optional (Some / Option setters). Default: false.

If trading strategy state should be saved to the database on stop.

pub fn maybe_save_state( self, value: Option<bool>, ) -> KernelConfigBuilder<SetSaveState<S>>
where S::SaveState: IsUnset,

Optional (Some / Option setters). Default: false.

If trading strategy state should be saved to the database on stop.

pub fn logging(self, value: LoggerConfig) -> KernelConfigBuilder<SetLogging<S>>
where S::Logging: IsUnset,

Optional (Some / Option setters). Default: <LoggerConfig as Default>::default().

The logging configuration for the kernel.

pub fn maybe_logging( self, value: Option<LoggerConfig>, ) -> KernelConfigBuilder<SetLogging<S>>
where S::Logging: IsUnset,

Optional (Some / Option setters). Default: <LoggerConfig as Default>::default().

The logging configuration for the kernel.

pub fn instance_id(self, value: UUID4) -> KernelConfigBuilder<SetInstanceId<S>>
where S::InstanceId: IsUnset,

Optional (Some / Option setters). The unique instance identifier for the kernel

pub fn maybe_instance_id( self, value: Option<UUID4>, ) -> KernelConfigBuilder<SetInstanceId<S>>
where S::InstanceId: IsUnset,

Optional (Some / Option setters). The unique instance identifier for the kernel

pub fn timeout_connection( self, value: Duration, ) -> KernelConfigBuilder<SetTimeoutConnection<S>>
where S::TimeoutConnection: IsUnset,

Optional (Some / Option setters). Default: Duration::from_secs(120).

The timeout for all clients to connect and initialize.

pub fn maybe_timeout_connection( self, value: Option<Duration>, ) -> KernelConfigBuilder<SetTimeoutConnection<S>>
where S::TimeoutConnection: IsUnset,

Optional (Some / Option setters). Default: Duration::from_secs(120).

The timeout for all clients to connect and initialize.

pub fn timeout_reconciliation( self, value: Duration, ) -> KernelConfigBuilder<SetTimeoutReconciliation<S>>
where S::TimeoutReconciliation: IsUnset,

Optional (Some / Option setters). Default: Duration::from_secs(30).

The timeout for execution state to reconcile.

pub fn maybe_timeout_reconciliation( self, value: Option<Duration>, ) -> KernelConfigBuilder<SetTimeoutReconciliation<S>>
where S::TimeoutReconciliation: IsUnset,

Optional (Some / Option setters). Default: Duration::from_secs(30).

The timeout for execution state to reconcile.

pub fn timeout_portfolio( self, value: Duration, ) -> KernelConfigBuilder<SetTimeoutPortfolio<S>>
where S::TimeoutPortfolio: IsUnset,

Optional (Some / Option setters). Default: Duration::from_secs(10).

The timeout for portfolio to initialize margins and unrealized pnls.

pub fn maybe_timeout_portfolio( self, value: Option<Duration>, ) -> KernelConfigBuilder<SetTimeoutPortfolio<S>>
where S::TimeoutPortfolio: IsUnset,

Optional (Some / Option setters). Default: Duration::from_secs(10).

The timeout for portfolio to initialize margins and unrealized pnls.

pub fn timeout_disconnection( self, value: Duration, ) -> KernelConfigBuilder<SetTimeoutDisconnection<S>>
where S::TimeoutDisconnection: IsUnset,

Optional (Some / Option setters). Default: Duration::from_secs(10).

The timeout for all engine clients to disconnect.

pub fn maybe_timeout_disconnection( self, value: Option<Duration>, ) -> KernelConfigBuilder<SetTimeoutDisconnection<S>>
where S::TimeoutDisconnection: IsUnset,

Optional (Some / Option setters). Default: Duration::from_secs(10).

The timeout for all engine clients to disconnect.

pub fn delay_post_stop( self, value: Duration, ) -> KernelConfigBuilder<SetDelayPostStop<S>>
where S::DelayPostStop: IsUnset,

Optional (Some / Option setters). Default: Duration::from_secs(10).

The delay after stopping the node to await residual events before final shutdown.

pub fn maybe_delay_post_stop( self, value: Option<Duration>, ) -> KernelConfigBuilder<SetDelayPostStop<S>>
where S::DelayPostStop: IsUnset,

Optional (Some / Option setters). Default: Duration::from_secs(10).

The delay after stopping the node to await residual events before final shutdown.

pub fn timeout_shutdown( self, value: Duration, ) -> KernelConfigBuilder<SetTimeoutShutdown<S>>
where S::TimeoutShutdown: IsUnset,

Optional (Some / Option setters). Default: Duration::from_secs(5).

The delay to await pending tasks cancellation during shutdown.

pub fn maybe_timeout_shutdown( self, value: Option<Duration>, ) -> KernelConfigBuilder<SetTimeoutShutdown<S>>
where S::TimeoutShutdown: IsUnset,

Optional (Some / Option setters). Default: Duration::from_secs(5).

The delay to await pending tasks cancellation during shutdown.

pub fn cache(self, value: CacheConfig) -> KernelConfigBuilder<SetCache<S>>
where S::Cache: IsUnset,

Optional (Some / Option setters). The cache configuration.

pub fn maybe_cache( self, value: Option<CacheConfig>, ) -> KernelConfigBuilder<SetCache<S>>
where S::Cache: IsUnset,

Optional (Some / Option setters). The cache configuration.

pub fn msgbus( self, value: MessageBusConfig, ) -> KernelConfigBuilder<SetMsgbus<S>>
where S::Msgbus: IsUnset,

Optional (Some / Option setters). The message bus configuration.

pub fn maybe_msgbus( self, value: Option<MessageBusConfig>, ) -> KernelConfigBuilder<SetMsgbus<S>>
where S::Msgbus: IsUnset,

Optional (Some / Option setters). The message bus configuration.

pub fn data_engine( self, value: DataEngineConfig, ) -> KernelConfigBuilder<SetDataEngine<S>>
where S::DataEngine: IsUnset,

Optional (Some / Option setters). The data engine configuration.

pub fn maybe_data_engine( self, value: Option<DataEngineConfig>, ) -> KernelConfigBuilder<SetDataEngine<S>>
where S::DataEngine: IsUnset,

Optional (Some / Option setters). The data engine configuration.

pub fn risk_engine( self, value: RiskEngineConfig, ) -> KernelConfigBuilder<SetRiskEngine<S>>
where S::RiskEngine: IsUnset,

Optional (Some / Option setters). The risk engine configuration.

pub fn maybe_risk_engine( self, value: Option<RiskEngineConfig>, ) -> KernelConfigBuilder<SetRiskEngine<S>>
where S::RiskEngine: IsUnset,

Optional (Some / Option setters). The risk engine configuration.

pub fn exec_engine( self, value: ExecutionEngineConfig, ) -> KernelConfigBuilder<SetExecEngine<S>>
where S::ExecEngine: IsUnset,

Optional (Some / Option setters). The execution engine configuration.

pub fn maybe_exec_engine( self, value: Option<ExecutionEngineConfig>, ) -> KernelConfigBuilder<SetExecEngine<S>>
where S::ExecEngine: IsUnset,

Optional (Some / Option setters). The execution engine configuration.

pub fn portfolio( self, value: PortfolioConfig, ) -> KernelConfigBuilder<SetPortfolio<S>>
where S::Portfolio: IsUnset,

Optional (Some / Option setters). The portfolio configuration.

pub fn maybe_portfolio( self, value: Option<PortfolioConfig>, ) -> KernelConfigBuilder<SetPortfolio<S>>
where S::Portfolio: IsUnset,

Optional (Some / Option setters). The portfolio configuration.

pub fn streaming( self, value: StreamingConfig, ) -> KernelConfigBuilder<SetStreaming<S>>
where S::Streaming: IsUnset,

Optional (Some / Option setters). The configuration for streaming to feather files.

pub fn maybe_streaming( self, value: Option<StreamingConfig>, ) -> KernelConfigBuilder<SetStreaming<S>>
where S::Streaming: IsUnset,

Optional (Some / Option setters). The configuration for streaming to feather files.